"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.destination = void 0;
const tslib_1 = require("tslib");
const shim_1 = require("@segment/browser-destination-runtime/shim");
const actions_core_1 = require("@segment/actions-core");
const trackEvent_1 = tslib_1.__importDefault(require("./trackEvent"));
const identifyUser_1 = tslib_1.__importDefault(require("./identifyUser"));
exports.destination = {
    name: 'ReplayBird Web (Actions)',
    slug: 'actions-replaybird-web',
    mode: 'device',
    presets: [
        {
            name: 'Track Event',
            subscribe: 'type = "track" or type = "page"',
            partnerAction: 'trackEvent',
            mapping: actions_core_1.defaultValues(trackEvent_1.default.fields),
            type: 'automatic'
        },
        {
            name: 'Identify User',
            subscribe: 'type = "identify"',
            partnerAction: 'identifyUser',
            mapping: actions_core_1.defaultValues(identifyUser_1.default.fields),
            type: 'automatic'
        }
    ],
    settings: {
        apiKey: {
            description: 'The api key for replaybird',
            label: 'API Key',
            type: 'string',
            required: true
        }
    },
    initialize: async ({ settings }, deps) => {
        await deps.loadScript(`https://cdn.replaybird.com/agent/latest/replaybird.js`);
        await deps.resolveWhen(() => Object.prototype.hasOwnProperty.call(window, 'replaybird'), 100);
        if (settings.apiKey) {
            window.replaybird.init(settings.apiKey, {});
            window.replaybird.apiKey = settings.apiKey;
        }
        return window.replaybird;
    },
    actions: {
        trackEvent: trackEvent_1.default,
        identifyUser: identifyUser_1.default
    }
};
exports.default = shim_1.browserDestination(exports.destination);
//# sourceMappingURL=index.js.map